@@ -4,17 +4,20 @@ Created on 2021-04-06
 @author: wf
 '''
 from lodstorage.jsonable import JSONAble,JSONAbleList
+from collections import OrderedDict
 from datetime import datetime
 from wikibot.wikiuser import WikiUser
 from wikibot.wikiclient import WikiClient
 from wikibot.wikipush import WikiPush
 from pathlib import Path
+from ormigrate.fixer import PageFixer
 import os
 import time
 
 from ormigrate.issue41 import AcronymLengthFixer
+from ormigrate.issue119_Ordinals import OrdinalFixer
 from ormigrate.painscale import PainScale
-
+from ormigrate.eventSeriesFixer import EventSeriesProvenanceFixer
 
 class OREntityList(JSONAbleList):
     '''
@@ -50,6 +53,7 @@ class OREntityList(JSONAbleList):
                 if value in lookup:
                     if withDuplicates:
                         lookupResult=lookup[value]
+                        lookupResult.append(entity)
                     else:
                         duplicates.append(entity)
                 else:
@@ -187,18 +191,27 @@ class OREntityList(JSONAbleList):
         
         Args:
             ratingCallback(func): a function to be called for rating of this entity
+            
+        Returns:
+            list: a list of dicts with the rating
         '''
         lod=[]
+        errors=[]
         for entity in self.getList():
-            eventRecord={'pageTitle':entity.pageTitle}
+            entityRecord=OrderedDict()
+            # pageTitle default attribute
+            if hasattr(entity,'pageTitle'):
+                entityRecord['pageTitle']=entity.pageTitle
             for propertyLookup in self.propertyLookupList:
                 name=propertyLookup['name']
                 if hasattr(entity,name):
-                    eventRecord[name]=getattr(entity,name)
+                    entityRecord[name]=getattr(entity,name)
             if ratingCallback is not None:
-                ratingCallback(entity,eventRecord)    
-            lod.append(eventRecord)
-        return lod
+                ratingErrors=ratingCallback(entity,entityRecord)   
+                if len(ratingErrors)>0:
+                    errors.append(ratingErrors) 
+            lod.append(entityRecord)
+        return lod,errors
         
 class EventSeriesList(OREntityList):
     '''
@@ -212,7 +225,7 @@ class EventSeriesList(OREntityList):
             { 'prop':'Homepage',   'name': 'homepage'},
             { 'prop':'Title',      'name': 'title'},
             #{ 'prop':'Field',      'name': 'subject'},
-            { 'prop':'Wikidataid',  'name': 'wikiDataId'},
+            { 'prop':'Wikidataid',  'name': 'wikidataId'},
             { 'prop':'DblpSeries',  'name': 'dblpSeries' }
         ]
         
@@ -268,6 +281,20 @@ class EventSeries(JSONAble):
 
         return samplesWikiSon
     
+    @classmethod       
+    def rateMigration(cls,eventSeries,eventSeriesRecord):
+        '''
+        get the ratings from the different fixers
+        '''
+        pageFixerList= [
+            {
+                "column": "provenance",
+                "fixer": EventSeriesProvenanceFixer
+            },
+        ]
+        return PageFixer.rateWithFixers(pageFixerList, eventSeries,eventSeriesRecord)
+        
+    
     def __str__(self):
         text=self.pageTitle
         if hasattr(self, "acronym"):
@@ -404,9 +431,20 @@ This CfP was obtained from [http://www.wikicfp.com/cfp/servlet/event.showcfp?eve
             
     @classmethod       
     def rateMigration(cls,event,eventRecord):
-        rating = AcronymLengthFixer.getRating(eventRecord)
-        eventRecord['acronym length'] = PainScale.lookupPainImage(rating)
-        pass
+        '''
+        get the ratings from the different fixers
+        '''
+        pageFixerList= [
+            {
+                "column": "acronym",
+                "fixer": AcronymLengthFixer
+            },
+            {
+                "column": "ordinal",
+                "fixer": OrdinalFixer
+            }
+        ]
+        return PageFixer.rateWithFixers(pageFixerList, event,eventRecord)
     
     def __str__(self):
         text=self.pageTitle
